---
title: Code of Conduct
---

## 1. Definitions

### 1.1. "Our Community"

Encompasses all platforms and spaces, both digital and physical, where members interact under our organization's auspices. This includes, but is not limited to:

- Our official Discord server
- Our code repositories and associated accounts
- Our official social media accounts and pages
- Any other online forums or platforms we officially endorse or manage
- In-person events organized or sponsored by our organization

### 1.2. "Community Members"

Refers to all individuals who participate in Our Community, regardless of their role or level of engagement. This includes casual users, regular contributors, and community leaders.

### 1.3. "Community Leaders"

Refers to individuals with official responsibilities within Our Community, including but not limited to:

- Moderators
- Developers
- Support staff
- Administrators
- Project managers
- Event organizers

### 1.4. "Code of Conduct" or "CoC"

Refers to this document in its entirety, including all sections, subsections, and any future amendments.

### 1.5. "Violating the Code of Conduct"

Means engaging in behavior that contradicts the guidelines, rules, and principles outlined in this document.

### 1.6. "Reporting"

Refers to the act of bringing a potential Code of Conduct violation to the attention of Community Leaders through officially designated channels.

### 1.7. "Sanctions"

Refers to the consequences imposed on community members who violate the Code of Conduct, as determined by Community Leaders.

### 1.8. "Platforms"

Refers to any digital or physical space where Our Community interacts, as listed in section 1.1.

## 2. Scope

### 2.1. Applicability

This Code of Conduct applies to all interactions within Our Community, including but not limited to:

- Public channels and forums
- Private channels and direct messages
- Online and offline community spaces
- Community-organized events and meetups
- Any form of communication using our official platforms or branding

### 2.2. Extended Scope

The Code of Conduct may also apply to interactions outside Our Community when:

- A Community Member is involved in an incident affecting another Community Member
- The incident has a substantial impact on the well-being or participation of Community Members
- The behavior significantly affects the reputation or integrity of Our Community

### 2.3. Temporal Scope

This Code of Conduct applies to:

- Current interactions within Our Community
- Past behavior of Community Members, including actions prior to joining Our Community
- Ongoing patterns of behavior that may have started before joining Our Community

### 2.4. Reporting

We encourage reporting of any violations of this Code of Conduct, including:

- Harassment by Community Members, especially Community Leaders
- Incidents that occur outside Our Community spaces
- Past incidents, regardless of when they took place

### 2.5. Commitment to Action

Community Leaders commit to:

- Take all good-faith reports seriously
- Respect the privacy and security of reporters
- Conduct fair and thorough investigations of reported incidents
- Take appropriate action based on the findings of investigations

### 2.6. Exclusion Rights

Community Leaders reserve the right to exclude individuals from Our Community based on:

- Violations of this Code of Conduct
- Past behavior, including actions outside Our Community spaces
- Behavior towards individuals who are not members of Our Community
- Any conduct deemed detrimental to the safety, well-being, or positive environment of Our Community

### 2.7. Scope of Authority

While this Code of Conduct primarily governs behavior within Our Community, we recognize that actions outside our spaces can significantly impact our environment. Therefore, Community Leaders may consider external behaviors when making decisions about community participation.

### 2.8. Amendments

The scope of this Code of Conduct may be amended as necessary to address emerging concerns or changing circumstances within Our Community. Any changes will be clearly communicated to all Community Members.

## 3. Rules and Prohibited Conduct

### 3.1. General Conduct

- No trolling, insulting, or derogatory comments.
- No harassment, whether public or private (see section 3.2 for detailed definition).
- No incitement of violence towards any individual, including encouraging suicide or self-harm.
- No deliberate "outing" of any aspect of a person's identity without their consent, except to protect vulnerable individuals from intentional abuse.
- No publication of non-harassing private communication without explicit consent from all parties involved.
- No advocating for members to be banned, except in direct messages to or private discussions with community leaders.
- No spam or excessive self-promotion.

### 3.2. Harassment

Harassment includes, but is not limited to:

- Deliberate misgendering or use of rejected names
- Unwanted physical contact or simulated physical contact without consent
- Threats of violence or intimidation
- Stalking or following
- Unwanted photography or recording, including logging online activity for harassment purposes
- Unwelcome sexual attention
- Pattern of inappropriate social contact, such as requesting/assuming inappropriate levels of intimacy
- Continued one-on-one communication after requests to cease
- Targeted and deliberate aggression
- Sustained disruption of discussion or community events

### 3.3. Respect for Identity and Diversity

- No questioning or challenging someone's stated self-identity or chosen labels.
- No unwelcome comments regarding a person's lifestyle choices and practices, including those related to food, health, parenting, relationships, drugs, and employment.
- No offensive comments related to gender, gender identity and expression, sexual orientation, disability, mental illness, neurodiversity, physical appearance, body size, age, race, national origin, ethnic origin, nationality, immigration status, language, religion or lack thereof, or other identity markers.
- No use or promotion of "reverse"-isms, including "reverse racism," "reverse sexism," and "cisphobia" against marginalized members.
- No debating the rights and lived experiences of marginalized people in the community.
- No racist, sexist, cissexist, ableist, or otherwise oppressive behavior, whether casual or explicit.

### 3.4. Oppression and Neutrality

:::caution
Neutrality in the face of oppression is to choose the side of the oppressor.
:::

We understand that not everyone may be aware of the struggles that underprivileged classes face. Asking questions to inform yourself is good.

But attempting to "bow out" of a discussion, or to claim you are remaining neutral when an under-represented person shares their experiences with oppression and anti-* legislation, is just as bad as siding against those underprivileged classes.

As such, behaviour like this is considered a violation of our Code of Conduct and will be actioned accordingly.

### 3.5. Content and Communication

- No explicit sexual images or behavior.
- No use of slurs or hateful terminology.
- Content warnings should be used when discussing potentially triggering topics.

### 3.6. Intellectual Property and Privacy

- Respect copyright and intellectual property rights.
- Do not share personal information of others without their explicit consent.

### 3.7. Community Discussions and Debates

- Engage in respectful and constructive dialogue.
- Be open to learning from others' perspectives.
- Avoid derailing discussions or intentionally inflaming tensions.

### 3.8. Reporting and Enforcement

- Report violations of this Code of Conduct to community leaders promptly.
- Cooperate with community leaders during investigations of reported incidents.
- Respect the privacy of individuals involved in reports and investigations.

### 3.9. Compliance with Platform-Specific Rules

- Adhere to the terms of service and community guidelines of any platforms used by Our Community.
- Be aware that certain behaviors may violate platform rules even if not explicitly mentioned in this Code of Conduct.

### 3.10. Amendments and Interpretations

- These rules may be amended or expanded as necessary to address emerging issues.
- Community leaders reserve the right to interpret these rules and make decisions in cases where the application of rules may be unclear.

## 4. Reporting and Response Procedures

### 4.1. Reporting Methods

- In Discord: Type @Moderator in any channel to alert community leaders.
- Direct Message: Contact a community leader directly via private message.
- Email: contact@nhcarrigan.com

### 4.2. Information to Include in Reports

- Your contact information (unless reporting anonymously)
- Names or descriptions of individuals involved
- Description of the incident, including date, time, and location (online or physical)
- Any relevant screenshots, chat logs, or other evidence
- Any additional context you believe is important

### 4.3. Handling of Reports

- We will respond to all reports as promptly as possible.
- If a reported violator is on our staff team, they will be immediately recused from handling the incident.
- All reports will be handled with discretion and confidentiality to the extent possible.

### 4.4. Confidentiality and Privacy

- We will respect confidentiality requests, especially to protect victims of abuse.
- Anonymous reporting options are available, though they may limit our ability to investigate.

### 4.5. Public Statements and Warnings

- At our discretion, we may publicly name a person about whom we've received harassment complaints.
- We may privately warn third parties about individuals if we believe it will increase community safety.
- We will not name harassment victims without their explicit, affirmative consent.

### 4.6. False Reports and Abuse of Process

- We reserve the right to reject reports we believe to have been made in bad faith.
- Reports intended to silence legitimate criticism may be dismissed without response.
- Deliberately false reporting is a violation of this Code of Conduct and may result in sanctions.

### 4.7. Protection of Reporters and Victims

- We will take all reasonable steps to protect reporters and victims from retaliation.
- Retaliation against reporters or victims is a serious violation of this Code of Conduct.

### 4.8. Investigation Process

- We will conduct a thorough and impartial investigation of all reports.
- Investigations will be conducted as quickly as possible while ensuring thoroughness.
- All parties involved will be given an opportunity to present their perspective.

### 4.9. Outcomes and Appeals

- After investigation, we will determine appropriate actions based on the evidence.
- We will communicate outcomes to involved parties as appropriate, respecting privacy concerns.
- An appeals process will be available for individuals who believe a decision was made in error.

### 4.10. Continuous Improvement

- We will regularly review our reporting and response procedures to ensure their effectiveness.
- Feedback on these procedures is welcome and will be considered for future improvements.

### 4.11. Support for Community Leaders

- We recognize the potential for burnout among our volunteer moderators and leaders.
- We will provide support and resources to our community leaders to help them manage their responsibilities effectively.

## 5. Sanctions and Enforcement

### 5.1. General Principles

- Participants must immediately comply when asked to stop any harmful behavior.
- Community leaders may take any appropriate action in response to harmful behavior.
- All sanctions will be applied fairly, consistently, and proportionally to the violation.

### 5.2. Authority of Community Leaders

- Community leaders have the right and responsibility to remove, edit, or reject contributions not aligned with this Code of Conduct.
- Leaders commit to applying these principles fairly and consistently in all aspects of community management.
- Leaders who fail to follow or enforce the Code of Conduct may be permanently removed from their position.

### 5.3 Sanction Criteria

The following list outlines the criteria used when determining if a sanction should be issued.

- Behaviour which violates this Code of Conduct, our Community Guidelines, or our other public policies.
- Behaviour which our staff feel is not in the spirit of the policy, even if it is not violating the letter of the policy.
- Repeated behaviour that has been previously sanctioned, as outlined in our escalation policy.
- Attempts to circumvent sanctions, such as ban evasion.

### 5.4. Privacy and Security

- All community leaders are obligated to respect the privacy and security of incident reporters.
- Information about sanctions will be shared on a need-to-know basis.

### 5.5. Gradated Sanction System

Community leaders will follow these Community Impact Guidelines in determining consequences:

#### 5.5.1. Level 1: Reminder

- Example Behavior: Use of inappropriate language or other behavior deemed unprofessional or unwelcome.
- Consequences:
  - A public, written reminder from community leaders
  - Clarification of the violation and why the behavior was inappropriate
  - A public apology may be requested

#### 5.5.2. Level 2: Warning

- Example Behavior: A violation through a single incident or series of actions.
- Consequences:
  - A formal warning
  - Clear communication of consequences for continued behavior
  - Incident is logged for future reference

#### 5.5.3. Level 3: Temporary Removal

- Example Behavior: A serious violation of community standards or sustained inappropriate behavior.
- Consequences:
  - Temporary removal from community platforms (e.g., Discord kick)
  - Clear conditions for return, including a cooling-off period
  - Requirement to re-read and acknowledge the Code of Conduct before rejoining

#### 5.5.4. Level 4: Permanent Ban

- Example Behavior: Pattern of violations, sustained inappropriate behavior, harassment, or aggression towards individuals or groups.
- Consequences:
  - Permanent ban from all community platforms
  - Public statement may be made, if deemed necessary for community safety

### 5.6. Additional Sanction Considerations

- Repeated violations will generally result in escalating sanctions.
- The severity of the violation may warrant skipping levels in the sanction system.
- Community leaders may impose additional requirements, such as public apologies or community service, as conditions for continued participation.

### 5.7. Appeals Process

- Individuals may appeal sanctions by [completing the form](/community/appeal)
- Appeals will be reviewed by leaders not involved in the original decision.
- During the appeal, the original sanction remains in effect.

### 5.8. Documentation and Transparency

- All formal sanctions will be publicised for review and consistency. Sanctions can be viewed at https://logs.nhcarrigan.com.
- Aggregate data on Code of Conduct violations and sanctions may be published periodically to ensure transparency.

### 5.9. Rehabilitation and Education

- Where appropriate, we will provide resources and support for individuals to learn from their mistakes and improve their behavior.
- For less severe violations, completion of educational programs may be offered as an alternative or supplement to other sanctions.

### 5.10. Legal Implications

- In cases of illegal activity, appropriate legal authorities may be notified.
- Our sanctions do not preclude or replace any legal action that may be warranted.

### 5.11. Regular Review

- This sanction system will be reviewed periodically to ensure its effectiveness and fairness.
- Community feedback on the sanction system is welcome and will be considered in reviews.

## 6. Moderation Logs and Transparency

### 6.1. Purpose of Moderation Logs

- To ensure transparency in moderation sanctions
- To maintain accountability of the moderation team to community members
- To provide a clear record of enforcement of the Code of Conduct

### 6.2. Scope of Logged Actions

- All moderation sanctions across all community platforms will be logged
- This includes, but is not limited to:
  - Warnings issued
  - Temporary removals or suspensions
  - Permanent bans
  - Appeals and their outcomes

### 6.3. Location of Moderation Logs

- All moderation sanctions will be publicly logged at https://logs.nhcarrigan.com
- The log will be accessible to all community members

### 6.4. Information Included in Logs

- Date and time of the action
- Type of action taken
- Reason for the action
- Platform where the violation occurred
- Identifier of the user who received the action
- Identifier of the leader who performed the action
- Any relevant evidence

### 6.5. Privacy Considerations

- In cases where privacy is crucial (e.g., harassment reports), certain details may be omitted or generalized

### 6.6. Accessibility of Logs

- The moderation log channel will be read-only for regular community members
- Community members can request clarification on logged sanctions through appropriate channels

### 6.7. Retention of Logs

- Moderation logs will be retained for a period of no less than 1 year.
  - After this period, logs may be archived or summarized for long-term record-keeping

### 6.8. Audit and Review

- Moderation logs will be periodically reviewed by community leadership to ensure consistency and fairness in enforcement
- Annual reports summarizing moderation actions may be published to the community

### 6.9. Dispute Resolution

- If a community member believes a moderation action was taken in error, they can refer to the logs and follow the appeals process outlined in the Sanctions section

### 6.10. Moderator Accountability

- Patterns of biased or inconsistent moderation will be addressed by community leadership
- Moderators who consistently fail to log their actions may have their privileges revoked

### 6.11. Feedback and Improvement

- Community members are encouraged to provide feedback on the moderation log system
- The logging process will be reviewed periodically and may be adjusted to better serve the community's needs

## 7. Advertising and Promotion

### 7.1. General Prohibition

- Advertising and self-promotion are generally not permitted within our community spaces.
- This includes, but is not limited to, unsolicited promotion of products, services, websites, social media accounts, or other communities.

### 7.2. Exceptions

- Links or information expressly requested by our team for support or moderation purposes.
- Sharing of resources directly relevant to ongoing discussions, when done in good faith and not for commercial gain.
- Official announcements or promotions approved by community leadership.

### 7.3. Support and Moderation Contexts

- Community members may be asked to provide links or information to assist with support inquiries or moderation investigations.
- In these cases, sharing such information is permitted and encouraged.

### 7.4. Relevance and Context

- Any shared links or information must be directly relevant to the current discussion or inquiry.
- The relevance and appropriateness of shared content will be at the discretion of community leaders.

### 7.5. Disclosure of Affiliations

- If sharing information about a product or service with which you have a personal or professional affiliation, this affiliation must be clearly disclosed.

### 7.6. Consequences of Violation

- Violations of this policy will be treated as a breach of the Code of Conduct.
- Consequences may range from content removal to temporary or permanent bans, depending on the severity and frequency of violations.

### 7.7. Appeals and Clarifications

- If you are unsure whether specific content would be considered advertising, consult with a community leader before posting.
- If your content is removed under this policy, you may appeal the decision through the established channels outlined in the Sanctions section.

## 8. Languages

### 8.1. Official Language

- The official language of our community is English.
- All community interactions, discussions, and contributions should be in English.

### 8.2. Scope of English-Only Policy

- This policy applies to all community spaces, including but not limited to:
  - Discord channels
  - GitHub discussions and issues
  - Documentation
  - Official communication channels

### 8.3. Multilingual Applications

- Even if our applications or services are offered in multiple languages, community discussions about them must be conducted in English.

### 8.4. Rationale

- To ensure clear communication among all community members.
- To facilitate effective moderation and support.
- To maintain consistency across all community platforms.

### 8.5. Exceptions

- Specific channels or sections designated for other languages, if explicitly created and approved by community leadership.
- Brief translations to assist non-native English speakers, when immediately followed by an English translation.

### 8.6. Support for Non-Native Speakers

- We encourage patience and understanding towards non-native English speakers.
- Community members are encouraged to help clarify or rephrase messages if there's a language barrier, while maintaining English as the primary language.

### 8.7. Translation Tools

- While automatic translation tools may be used personally, the original English content should be included in all community interactions.
