---
title: Privacy Policy
---

## 1. Overview and Scope

### 1.1. General Applicability

This privacy policy ("General Policy") governs the collection, use, storage, and protection of data across all our services, platforms, and applications (collectively referred to as "Services").

### 1.2. Project-Specific Policies

Individual projects or Services may be subject to additional, project-specific privacy policies ("Project Policies"). These Project Policies apply concurrently with the General Policy. In the event of any conflict between the General Policy and a Project Policy, the stricter privacy protections shall prevail.

### 1.3. Policy Updates and Retroactivity

We reserve the right to modify, amend, or update this General Policy and any Project Policies at any time. All changes to these policies, including the General Policy and any Project Policies, are retroactive and apply to previously collected data as well as data collected after the changes take effect.

### 1.4. Notification of Changes

We will make reasonable efforts to notify users of significant changes to our privacy policies. However, it is the user's responsibility to regularly review the applicable privacy policies for any updates.

### 1.5. Acceptance of Terms

By accessing, using, or continuing to use our Services, you explicitly acknowledge and agree to be bound by the most current version of the General Policy and any applicable Project Policies. If you do not agree with the terms of these policies, you must immediately cease using our Services.

### 1.6. Effective Date

The effective date of the current version of this policy will be clearly stated at the beginning of the document. Each revision will be numbered or dated for easy reference.

## 2. Data Collection, Documentation, and User Rights

### 2.1. Data Collection Practices

We strive to collect only the data necessary for the proper functioning and improvement of our Services. However, the scope of data collection may change as our Services evolve.

### 2.2. Documentation Efforts

We make every effort to maintain accurate and up-to-date documentation regarding our data collection practices. This includes:

- Regular reviews of our data collection processes
- Timely updates to our privacy policy and related documentation
- Clear communication about significant changes in data collection

### 2.3. Potential Undocumented Data Collection

Despite our best efforts, it is possible that at any given time, an application or Service may collect data that is not explicitly documented. This may occur due to:

- Recent updates or changes to our Services
- Technical issues or bugs
- Third-party integrations or dependencies

### 2.4. General Data Rights

Regardless of whether specific data collection is documented, users have the following rights:

#### 2.4.1. Right to Access:

At any time, you may request a complete copy of your data stored by one of our applications. Requests must be done via `privacy@nhcarrigan.com` from the email address the data belongs to. This ensures that a user cannot impersonate you and request your data. We may request additional identifying information, depending on the structure of the data collected by the application.

#### 3.4.2. Right to Rectification:

You may request corrections to any inaccurate data we hold about you.

#### 3.4.3. Right to Erasure:

At any time, you may request complete removal of your stored data. Requests must be done via `privacy@nhcarrigan.com` from the email address the data belongs to. This ensures that a user cannot impersonate you and request your data. We may request additional identifying information, depending on the structure of the data collected by the application.

This will **not** opt you out of future data collection unless specifically requested. We reserve the right to refuse removal requests when the data are necessary for specific functionality of the app, in circumstances where removing your data would compromise the functionality for all users.

#### 3.4.4. Right to Restrict Processing:

At any time, you may request to opt out of data collection for an application by requesting removal of your data and discontinuing interaction with the application. We may request additional identifying information, depending on the structure of the data collected by the application.

We reserve the right to refuse opt-out requests when the data are necessary for specific functionality of the app, in circumstances where opting-out would compromise the functionality for all users.

#### 3.4.5. Right to Data Portability:

You may request a copy of your data in a structured, commonly used, and machine-readable format.

### 3.5. Exercising Your Rights

To exercise any of these rights or to inquire about data we may hold:

- Contact us through `privacy@nhcarrigan.com`.
- Be prepared to verify your identity to protect the security of your information

### 3.6. Opting Out of Data Collection

- You may cease using our Services
- For specific types of data collection, we may offer granular opt-out options
- Note that opting out of essential data collection may limit or prevent your use of certain Services

### 3.7. Response Time and Process

We will make reasonable efforts to respond to all data-related requests within 30 days. Complex requests may require additional time, in which case we will notify you.

### 3.8. Limitations

While we strive to honour all legitimate requests, be aware that legal requirements may sometimes prevent us from fully complying with certain requests.

### 3.9. Ongoing Commitment

We are committed to transparency and user privacy. We continuously work to improve our data practices and documentation to ensure the highest standards of data protection and user trust.

## 4. Data Retention

### 4.1. Retention Principle

We adhere to the principle of data minimization, storing personal data for the shortest time necessary to fulfil the purposes for which it was collected and to ensure the proper functioning of our applications.

### 4.2. Retention Periods

Specific retention periods may vary depending on the type of data and the purpose for which it is processed. Generally:

- Active user data is retained for the duration of the user's account activity
- Inactive user data may be retained for a period after the last user interaction, typically not exceeding 12 months
- Aggregated and anonymized data may be retained indefinitely for analytical purposes

### 4.3. Automatic Deletion

Where technically feasible, we implement automated processes to delete or anonymize personal data that has exceeded its retention period.

### 4.4. Legal and Regulatory Compliance

Certain data may be retained for longer periods if required by applicable laws, regulations, or to comply with legal obligations.

### 4.5. Backup Retention

For data recovery purposes, backups may contain personal data for a period beyond the active retention period. These backups are secured and accessed only when necessary for system restoration.

### 4.6. User-Initiated Deletion

Users may request the deletion of their data at any time, subject to our legitimate business needs and legal obligations.

## 5. Availability of Data

### 5.1. Access Control

Access to user data is strictly controlled and limited to authorized members of the nhcarrigan team on a need-to-know basis.

### 5.2. Purpose Limitation

Data access by the nhcarrigan team is permitted only for the following purposes:

- Debugging application issues
- Improving application functionality and user experience
- Contributing to the development and maintenance of the application
- Responding to user support requests
- Ensuring compliance with legal and regulatory requirements

### 5.3. Data Security Measures

We implement robust security measures to protect data from unauthorized access, including but not limited to:

- Encryption of data in transit and at rest
- Multi-factor authentication for developer accounts
- Regular security audits and vulnerability assessments
- Logging of data access and modifications

### 5.4. Developer Training and Accountability

All team members with data access are:

- Required to undergo privacy and security training
- Bound by confidentiality agreements
- Subject to disciplinary action for unauthorized data access or misuse

### 5.5. Third-Party Access

We do not sell user data. In cases where third-party service providers require access to perform specific functions:

- Access is limited to the minimum necessary data
- Providers are bound by strict contractual obligations to protect user data
- We regularly review and audit third-party practices

### 5.6. Transparency

We maintain logs of data access by our team and can provide this information upon justified request, subject to privacy and security considerations.

### 5.7. User Data Requests

Users may request information about how their data has been accessed or used by contacting our designated data protection contact.

### 5.8. Continuous Improvement

We regularly review and update our data handling practices to ensure the highest standards of data protection and to minimize unnecessary access to personal information.

## 6. Contact Information and Data Inquiries

We value transparency and are committed to addressing any questions or concerns you may have regarding our privacy practices. There are several ways to reach us:

### 6.1. Forum

For immediate assistance and community support, join our forum: https://forum.nhcarrigan.com

### 6.2. Email Contact

For privacy-specific inquiries or formal requests, please email: `privacy@nhcarrigan.com`

### 6.3. Response Time

We strive to respond to all inquiries within 5 business days. Complex issues may require additional time.

### 6.4. Types of Inquiries

We welcome contact regarding:

- Questions about this privacy policy
- Inquiries about our data collection and use practices
- Requests to exercise your data rights (access, rectification, erasure, etc.)
- Reporting of potential data breaches or security concerns
- Suggestions for improving our privacy practices

### 6.5. Information to Include

To help us address your inquiry efficiently, please include:

- Your full name
- The email address associated with your account (if applicable)
- A detailed description of your question or concern
- Any relevant dates, times, or specific instances related to your inquiry

### 6.6. Verification Process

For security reasons, we may need to verify your identity before processing certain requests, especially those related to personal data.

### 6.7. Alternative Contact Methods

If you are unable to use Discord or email, please visit our website for additional contact options: https://nhcarrigan.com

### 6.8. Updates and Notifications

If you wish to receive updates about changes to our privacy policy or data practices, please bookmark this page.

### 6.9. Legal Inquiries

For legal or formal inquiries, please use the email provided above and clearly mark your message as a legal inquiry.

### 6.10. Accessibility

If you require this information in an alternative format for accessibility reasons, please let us know, and we will do our best to accommodate your needs.
